@@ -190,7 +190,17 @@ class Save:
     def createdb(self):
         conn = sqlite3.connect(self.savepath)
         c = conn.cursor()
-        c.execute('''CREATE TABLE movie
+        c.execute('''CREATE TABLE briefinfo
+              (uid             TEXT PRIMARY KEY ,
+               title           TEXT,
+               date        CHAR(10),
+               javdb_link        CHAR(50),
+               img          TEXT,
+               tags         TEXT
+               );''')
+        conn.commit()
+        print("成功创建表 briefinfo")
+        c.execute('''CREATE TABLE detailinfo
               (id             TEXT PRIMARY KEY ,
                date           CHAR(10),
                runtime        INTEGER DEFAULT 0,
@@ -212,10 +222,13 @@ class Save:
                previewimages  TEXT,
                magnets        TEXT
                );''')
-        print("成功创建表")
+
         conn.commit()
+        print("成功创建表 detailinfo")
         conn.close()
 
+
+
     def save(self, detailinfo):
         if not os.path.exists(self.savepath):self.createdb()
         conn = sqlite3.connect(self.savepath)
